@@ -14,7 +14,7 @@ use MIME::Type;
 
 use vars qw/$NS/;
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 =head1 NAME
 
@@ -79,45 +79,118 @@ sub _sanatize_filename {
 }
 
 sub _write_file {
-    my $upload = shift;
-    my $primcat = shift;
-    my $docroot = shift;
+    my %args = @_;
     my $fh = new IO::File;
-    my ($filename, $ext) = $upload->filename =~ m/^(.*)\.(\w*)$/;
+    my $filename = $args{filename};
+    my $ext = $args{extension} || 'txt';
+    if ($args{upload}) {
+	($filename, $ext) = $args{upload}->filename =~ m/^(.*)\.(\w*)$/;
+    }
     $filename = _sanatize_filename($filename);
-    my $lookupfile = $docroot ."/articles/content/$primcat/$filename/";
-    mkdir $lookupfile, 0775 || die "Failed to create directory " . $lookupfile;
+    my $i = 0;
+    while (-e $args{docroot} ."/articles/content/$args{primcat}/$filename/$filename.$ext") { # Append an incrementing number if the file exists
+	$i++;
+	if ($i == 1) {
+	    $filename .= '-' . $i;
+	} else {
+	    $filename =~ s/-\d+$/-$i/;
+	}
+	die "Can't really be $i identical files here, can it?" if ($i >= 100);
+    }
+    my $lookupfile = $args{docroot} ."/articles/content/$args{primcat}/$filename/";
+    my $dir;
+    foreach my $name (split('/', $lookupfile)) { # Make sure all dirs exist
+	$dir .= $name . '/';
+	unless (-d $dir) {
+	    mkdir ($dir, 0775) || die "Failed to create directory " . $dir;
+	}
+    }
     $lookupfile .= "$filename.$ext";
     if ($fh->open("> " . $lookupfile)) {
-	my $uploadedfh = $upload->fh;
-	while (<$uploadedfh>) {
-	    print $fh $_;
+	if ($args{upload}) {
+	    my $uploadedfh = $args{upload}->fh;
+	    while (<$uploadedfh>) {
+		print $fh $_;
+	    }
+	} else {
+	    die "Error saving string to filename $filename.$ext" unless (($filename) && ($args{text}));
+	    print $fh $args{text};
 	}
 	$fh->close;
     } else { die "Failed to open file at $lookupfile for writing"  }
-    return "/articles/content/$primcat/$filename/$filename.$ext";
+    return $filename;
 }
 
 package AxKit::App::TABOO::XSP::Article::Handlers;
 
 =head1 Tag Reference
 
+
+=head2 C<E<lt>store-required/E<gt>>
+
+This tag will check and store the data from the required fields. It
+will check for either uploaded files, and the MIME types of that, or
+take plain text and save it to a local file. It doesn't do many
+security checks yet.
+
+If the save was successful, it will redirect to C</articles/edit>, so
+that the submitter can continue editing of non-required fields.
+
+If something went wrong, the tag will return a nodelist
+C<problem>. The nodelist will contain the data store name of the
+field(s) that weren't present, or C<nosave> if the save itself failed.
+
 =cut
 
 
-sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Article/Output}store) {
-    return << 'EOC'
-      my $fh = new IO::File;
-      my $upload =  $cgi->upload->fh;
-      if ($fh->open("> /tmp/dahut")) {
-      while (<$upload>) {
-        print $fh $_;
-}
-        $fh->close;
+sub store_required : nodelist({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Article/Output}art:problem) {
+  return << 'EOC'
+  my @errors = ();
+  foreach my $required (qw(title authorid description primcat code)) {
+      unless ($cgi->param($required)) {
+	  push(@errors, $required);
+      }
+  }
+  unless ((($cgi->param('text')) && ($cgi->param('filename'))) || ($cgi->param('upfile'))) {
+      foreach my $required (qw(text filename upfile)) {
+	  unless ($cgi->param($required)) {
+	      push(@errors, $required);
+	  }
+      }
+  }
 
-    } else { die "screaming" }
-
-    1;
+  unless (@errors) { # OK, so far, so good
+      my %args = map { $_ => $cgi->param($_) } $cgi->param;
+      
+      my $upload = $cgi->upload;
+      if ($upload->size > 0) {
+	  $args{'filename'} = AxKit::App::TABOO::XSP::Article::_write_file(upload=>$upload, primcat => $args{'primcat'}, docroot=>$r->document_root);
+	  $args{'mimetype'} = $upload->type;
+      } else {
+	  $args{'filename'} = AxKit::App::TABOO::XSP::Article::_write_file(filename=>$args{'filename'}, text=>$args{'text'}, primcat => $args{'primcat'}, docroot=>$r->document_root);
+	  $args{'mimetype'} = 'text/plain';
+      }
+      # TODO: Security sanity checks.
+      $args{'authorok'} = 1; # Is assumed for now
+      unless ($args{'date'}) {
+	  my $timestamp = localtime;
+	  $args{'date'} = $timestamp->datetime;
+      }
+      my $article = AxKit::App::TABOO::Data::Article->new();
+      $article->populate(\%args, [[$args{'primcat'}, 'primcat']], [$args{'authorid'}]);
+      unless($article->save) {
+	  push(@errors, 'nosave');
+      }
+  }
+      
+  unless (@errors) { # Actually, everything went fine here, so we redirect to continue
+    $cgi->status(302);
+    $cgi->err_headers_out->add("Location" => '/articles/edit');
+    Apache::exit(302);
+  } else { 
+    AxKit::Debug(9, "Things that went wrong: " . join(' ', @errors));
+  }
+  @errors;
 EOC
 }
 
@@ -151,16 +224,24 @@ EOC
 }
 
 
+=head2 C<E<lt>get-article filename="foo" primcat="bar"/E<gt>>
+
+This tag will get an XML representation of the article identified with
+C<filename> and C<primcat>. The parameters may be given as attributes
+or child elements.
+
+=cut
+
 
 sub get_article : struct attribOrChild(filename,primcat) {
     return << 'EOC'
+    AxKit::Debug(8, "We look for article with filename: '" . $attr_filename . "'");
     my $article = AxKit::App::TABOO::Data::Article->new();
     unless ($article->load(limit => { filename => $attr_filename })) {
 	throw Apache::AxKit::Exception::Retval(
 					       return_code => 404,
 					       -text => "Article with identifier $attr_filename not found");
     }	
-
     unless ($article->editorok && $article->authorok) {
 	if (! $Apache::AxKit::Plugin::BasicSession::session{authlevel}) {
 	    throw Apache::AxKit::Exception::Retval(
@@ -182,6 +263,7 @@ sub get_article : struct attribOrChild(filename,primcat) {
     my $lookupurl;
     foreach my $ext ($article->mimetype->extensions) {
 	my $lookupfile = "/articles/content/$attr_primcat/$attr_filename/$attr_filename.$ext";
+	warn $r->document_root . $lookupfile;
 	if (-r $r->document_root . $lookupfile) {
 	    $lookupurl = 'http://' . $r->get_server_name . ':' . $r->get_server_port . $lookupfile;
 	}
